@@ -116,7 +116,7 @@ class Commandor(Mixin):
         :param options: list of additional :class:`~optparse.Option` objects
         """
         self.parser = parser
-        self._args = args
+        self._args = args or sys.argv[1:]
         self._options = options
         self._curdir = None
 
@@ -151,13 +151,14 @@ class Commandor(Mixin):
         :returns: return True for continue
         """
 
-        if options.list_commands():
+        if options.list_commands:
             self.show_commands()
 
-        if not any([arg for arg in args if not arg.startswith('-')]):
+        if isinstance(args, (list, tuple)) and\
+               not any([arg for arg in args if not arg.startswith('-')]):
             self.parser.print_help()
 
-        return True
+        return False
 
     def process(self):
         """Process parsing
@@ -176,7 +177,7 @@ class Commandor(Mixin):
             return res
 
         command, args = self.__class__.find_command(commands_args)
-        command_instance = command(cur_dir=self._curdir, args=args)
+        command_instance = command(cur_dir=self._curdir, args=args, commandor_res=res)
         return command_instance.process()
 
     @classmethod
@@ -239,10 +240,11 @@ class Command(Mixin):
 
     help = None
 
-    def __init__(self, parser=None, args=[], cur_dir=None):
+    def __init__(self, parser=None, args=[], cur_dir=None, commandor_res=None):
         self._args = args
         self.parser = parser
         self._cur_dir = cur_dir
+        self._commandor_res = commandor_res
 
     def initialize_parser(self):
         """Create :class:`optparse.OptionParse`
